import React, { useEffect, useState } from "react";
import { useNavigate } from "react-router-dom";
import axios from "axios";
import Sidebar from "./Sidebar";
import Topbar from "./Topbar"; // New Top Navbar component

const API_BASE_URL = "http://localhost:5000";

const Dashboard = () => {
  const navigate = useNavigate();

  useEffect(() => {
    const abortController = new AbortController();

    const checkSession = async () => {
      try {
        await axios.get(`${API_BASE_URL}/api/auth/session`, {
          withCredentials: true,
          signal: abortController.signal,
        });
      } catch (error) {
        console.log("Session expired. Logging out...");
        handleLogout();
      }
    };

    const handleLogout = async () => {
      try {
        await axios.post(`${API_BASE_URL}/api/auth/logout`, {}, { withCredentials: true });
      } catch (err) {
        console.error("Logout failed:", err);
      }
      document.cookie = "session_token=; expires=Thu, 01 Jan 1970 00:00:00 UTC; path=/;";
      navigate("/", { replace: true });
    };

    const interval = setInterval(checkSession, 30000);

    return () => {
      clearInterval(interval);
      abortController.abort();
    };
  }, [navigate]);

  return (
    <div className="flex h-screen bg-[#CCF2EC]">
      {/* Sidebar */}
      <Sidebar />

      {/* Main Content */}
      <div className="flex-1 flex flex-col">
        {/* Top Navbar */}
        <Topbar />

        {/* Dashboard Content */}
        <div className="p-6 flex flex-wrap gap-6">
        <div className="bg-white p-4 rounded-xl shadow-md w-[450px] h-[300px]">
  <h2 className="font-semibold text-[#136D5E]">Statistics and Summary</h2>
</div>

          <div className="bg-white p-4 rounded-xl shadow-md w-full md:w-1/2">
            <h2 className="font-semibold text-[#136D5E]">Today's Sales</h2>
          </div>
          <div className="bg-white p-4 rounded-xl shadow-md w-full ">
            <h2 className="font-semibold text-[#136D5E]">Other Details</h2>
          </div>
        </div>
      </div>
    </div>
  );
};

export default Dashboard;


